==> v0.1.2.zip: infinity-for-lemmy/README.md <==
<h1 align="center">
  Eternity for Lemmy
</h1>

<div align="center">

A Lemmy client for Android written in Java. It's a fork of the [Infinity for Reddit](https://github.com/Docile-Alligator/Infinity-For-Reddit) project, currenty in early development.

</div>

<br>
<div align="center">
<img src="https://codeberg.org/Bazsalanszky/Eternity/raw/branch/master/fastlane/metadata/android/en-US/images/icon.png" width=256>

[![status-badge](https://ci.codeberg.org/api/badges/12474/status.svg)](https://ci.codeberg.org/repos/12474)
[![Liberapay patrons](https://img.shields.io/liberapay/patrons/bazsalanszky)](https://liberapay.com/Bazsalanszky)

<a href="https://codeberg.org/Bazsalanszky/Eternity/issues">Report a Bug</a>

</div>

<div align="center">
<a href="https://play.google.com/store/apps/details?id=eu.toldi.infinityforlemmy">
    <img src="./.assets/google-play-badge.png" height="80">
</a>
<a href="https://apt.izzysoft.de/fdroid/index/apk/eu.toldi.infinityforlemmy">
    <img src="./.assets/IzzyOnDroid.png" height="80">
</a>
<a href="https://codeberg.org/Bazsalanszky/Eternity/releases/">
    <img src="./.assets/codeberg.png" height="80">
</a>



</div>

---

## Features

Eternity is currently in the early stages of development. Expect many unfinished features and bugs!

### Browsing Lemmy

 - Explore various feeds (Subscribed/Local/All) and communities
 - Subscribe or unsubscribe from specific communities, with the option to block
 - Discover communities federated with the current instance
 - Favorite a community for quick access
 - Manage your subscriptions and blocked communities

### Content Engagement

- Engage with content by voting, saving, sharing, and creating posts or comments
- Enjoy endless scrolling through feeds and posts
- Tailor the view settings for posts (card,compact, gallery)
- Set default preferences for post and comment sorting
- Stay updated with notifications for replies

### Account Management

- Sign in to multiple accounts or instances, and effortlessly switch between them
- Use the inbox features to view replies, mentions, and private messages
- Access your profile to view your posts, comments, and saved content

### Customization

- Choose between various theme options including Light, Dark, OLED
- Support Material You theming
- Explore user-created themes
- Customize font settings
- Optional bottom navigation bar
- Discover a plethora of other customization features

<img 
  src="https://codeberg.org/Bazsalanszky/Eternity/raw/branch/master/fastlane/metadata/android/en-US/images/phoneScreenshots/1.png" 
  alt="Screenshot 1"
  height="200" >
<img 
  src="https://codeberg.org/Bazsalanszky/Eternity/raw/branch/master/fastlane/metadata/android/en-US/images/phoneScreenshots/2.png" 
  alt="Screenshot 2"
  height="200" >
<img 
  src="https://codeberg.org/Bazsalanszky/Eternity/raw/branch/master/fastlane/metadata/android/en-US/images/phoneScreenshots/3.png" 
  alt="Screenshot 3"
  height="200" >
<img 
  src="https://codeberg.org/Bazsalanszky/Eternity/raw/branch/master/fastlane/metadata/android/en-US/images/phoneScreenshots/4.png" 
  alt="Screenshot 4"
  height="200" >
<img 
  src="https://codeberg.org/Bazsalanszky/Eternity/raw/branch/master/fastlane/metadata/android/en-US/images/phoneScreenshots/5.png" 
  alt="Screenshot 5"
  height="200" >


## Contributing

First off, thanks for taking the time to contribute! Contributions are what makes the open source community such an amazing place to learn, inspire, and create. Any contributions you make are **greatly appreciated**.

If you have a suggestion that would make this better, please fork the repo and create a pull request.
It's better to also open an issue describing the issue you want to fix. But it is not required.

Don't forget to give the project a star! Thanks again!

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

### Translation

You can alos help Eternity by translating it to your native langugage! Translations are done via [Weblate](https://translate.codeberg.org/projects/infinity-for-lemmy/app/)!

[![Translation](https://translate.codeberg.org/widgets/infinity-for-lemmy/-/app/multi-auto.svg)](https://translate.codeberg.org/engage/Eternity/)

### Reporting bugs

You can also contribute by [reporting bugs](https://codeberg.org/Bazsalanszky/Eternity/issues)

<p align="right">(<a href="#top">back to top</a>)</p>

## License

Distributed under the AGPL-3.0 License. See <a href="https://codeberg.org/Bazsalanszky/Eternity/src/branch/master/LICENSE">LICENSE</a> for more information.

<p align="right">(<a href="#top">back to top</a>)</p>

## Contact

[@bazsalanszky@lemmy.toldi.eu](https://lemmy.toldi.eu/u/bazsalanszky) - (Owner)

Project Link: [https://codeberg.org/Bazsalanszky/Eternity](https://codeberg.org/Bazsalanszky/Eternity)

<p align="right">(<a href="#top">back to top</a>)</p>

==> v0.2.0.zip: infinity-for-lemmy/README.md <==
<h1 align="center">
  Eternity for Lemmy
</h1>

<div align="center">

A Lemmy client for Android written in Java. It's a fork of the [Infinity for Reddit](https://github.com/Docile-Alligator/Infinity-For-Reddit) project, currenty in early development.

</div>

<br>
<div align="center">
<img src="https://codeberg.org/Bazsalanszky/Eternity/raw/branch/master/fastlane/metadata/android/en-US/images/icon.png" width=256>

[![status-badge](https://ci.codeberg.org/api/badges/12474/status.svg)](https://ci.codeberg.org/repos/12474)
[![Liberapay patrons](https://img.shields.io/liberapay/patrons/bazsalanszky)](https://liberapay.com/Bazsalanszky)
[![Lemmy Community](https://img.shields.io/lemmy/eternityapp@lemdro.id?style=flat-square&logo=lemmy&label=lemmy)](https://lemdro.id/c/eternityapp)

<a href="https://codeberg.org/Bazsalanszky/Eternity/issues">Report a Bug</a>

</div>

<div align="center">
<a href="https://f-droid.org/packages/eu.toldi.infinityforlemmy/">
    <img src="./.assets/fdroid-badge.png" height="80">
</a>
<a href="https://play.google.com/store/apps/details?id=eu.toldi.infinityforlemmy">
    <img src="./.assets/google-play-badge.png" height="80">
</a>

<a href="https://codeberg.org/Bazsalanszky/Eternity/releases/">
    <img src="./.assets/codeberg.png" height="80">
</a>



</div>

---

## Features

Eternity is currently in the early stages of development. Expect many unfinished features and bugs!

### Browsing Lemmy

 - Explore various feeds (Subscribed/Local/All) and communities
 - Subscribe or unsubscribe from specific communities, with the option to block
 - Discover communities federated with the current instance
 - Favorite a community for quick access
 - Manage your subscriptions and blocked communities

### Content Engagement

- Engage with content by voting, saving, sharing, and creating posts or comments
- Enjoy endless scrolling through feeds and posts
- Tailor the view settings for posts (card,compact, gallery)
- Set default preferences for post and comment sorting
- Stay updated with notifications for replies

### Account Management

- Sign in to multiple accounts or instances, and effortlessly switch between them
- Use the inbox features to view replies, mentions, and private messages
- Access your profile to view your posts, comments, and saved content

### Customization

- Choose between various theme options including Light, Dark, OLED
- Support Material You theming
- Explore user-created themes
- Customize font settings
- Optional bottom navigation bar
- Discover a plethora of other customization features

<img 
  src="https://codeberg.org/Bazsalanszky/Eternity/raw/branch/master/fastlane/metadata/android/en-US/images/phoneScreenshots/1.png" 
  alt="Screenshot 1"
  height="200" >
<img 
  src="https://codeberg.org/Bazsalanszky/Eternity/raw/branch/master/fastlane/metadata/android/en-US/images/phoneScreenshots/2.png" 
  alt="Screenshot 2"
  height="200" >
<img 
  src="https://codeberg.org/Bazsalanszky/Eternity/raw/branch/master/fastlane/metadata/android/en-US/images/phoneScreenshots/3.png" 
  alt="Screenshot 3"
  height="200" >
<img 
  src="https://codeberg.org/Bazsalanszky/Eternity/raw/branch/master/fastlane/metadata/android/en-US/images/phoneScreenshots/4.png" 
  alt="Screenshot 4"
  height="200" >
<img 
  src="https://codeberg.org/Bazsalanszky/Eternity/raw/branch/master/fastlane/metadata/android/en-US/images/phoneScreenshots/5.png" 
  alt="Screenshot 5"
  height="200" >


## Contributing

First off, thanks for taking the time to contribute! Contributions are what makes the open source community such an amazing place to learn, inspire, and create. Any contributions you make are **greatly appreciated**.

If you have a suggestion that would make this better, please fork the repo and create a pull request.
It's better to also open an issue describing the issue you want to fix. But it is not required.

Don't forget to give the project a star! Thanks again!

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

### Translation

You can also help Eternity by translating it to your native langugage! Translations are done via [Weblate](https://translate.codeberg.org/projects/infinity-for-lemmy/app/)!

[![Translation](https://translate.codeberg.org/widgets/infinity-for-lemmy/-/app/multi-auto.svg)](https://translate.codeberg.org/engage/Eternity/)

### Reporting bugs

You can also contribute by [reporting bugs](https://codeberg.org/Bazsalanszky/Eternity/issues)

<p align="right">(<a href="#top">back to top</a>)</p>

## License

Distributed under the AGPL-3.0 License. See <a href="https://codeberg.org/Bazsalanszky/Eternity/src/branch/master/LICENSE">LICENSE</a> for more information.

<p align="right">(<a href="#top">back to top</a>)</p>

## Contact

[@bazsalanszky@lemmy.toldi.eu](https://lemmy.toldi.eu/u/bazsalanszky) - (Owner)

Project Link: [https://codeberg.org/Bazsalanszky/Eternity](https://codeberg.org/Bazsalanszky/Eternity)

<p align="right">(<a href="#top">back to top</a>)</p>
